@@ -11,6 +11,10 @@ def upload(args):
     use_tar = args.use_tar
     use_control_signal = args.use_control_signal
     signal_path = args.signal_path
+    if not id:
+        id = os.environ.get('OSS_ID')
+    if not secret:
+        secret = os.environ.get('OSS_SECRET')
     if use_control_signal:
         with open(signal_path, 'w') as f:
             f.write('0')
@@ -50,6 +54,10 @@ def upload(args):
 def download(args):
     id = args.id
     secret = args.secret
+    if not id:
+        id = os.environ.get('OSS_ID')
+    if not secret:
+        secret = os.environ.get('OSS_SECRET')
     bucket_name = args.bucket
     local_path = args.local
     object_name = args.object
